// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "assert/assert.hpp"
#include "EntityDirection.hpp"

using namespace Dawn;

glm::vec3 entityDirectionGetVector(const EntityDirection &dir) {
  switch(dir) {
    case EntityDirection::Up: return glm::vec3(0.0f, 1.0f, 0.0f);
    case EntityDirection::Down: return glm::vec3(0.0f, -1.0f, 0.0f);
    case EntityDirection::Left: return glm::vec3(-1.0f, 0.0f, 0.0f);
    case EntityDirection::Right: return glm::vec3(1.0f, 0.0f, 0.0f);
    default:
      assertUnreachable("Invalid direction: %d", dir);
      return glm::vec3(0.0f, 0.0f, 0.0f);
  }
}

struct EntityTilePosition entityDirectionGetRelativeTilePosition(
  const EntityTilePosition &pos,
  const EntityDirection &dir,
  int32_t distance
) {
  struct EntityTilePosition result = pos;
  switch(dir) {
    case EntityDirection::Up: result.z -= distance; break;
    case EntityDirection::Down: result.z += distance; break;
    case EntityDirection::Left: result.x -= distance; break;
    case EntityDirection::Right: result.x += distance; break;
    default:
      assertUnreachable("Invalid direction: %d", dir);
      break;
  }
  return result;
}