// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawnlibs.hpp"
#include "EntityTilePosition.hpp"

enum class EntityDirection : uint8_t {
  Up,
  Down,
  Left,
  Right,
};

/**
 * Gets the vector for the given direction.
 * 
 * @param dir The direction to get the vector for.
 * @return The vector for the given direction.
 */
glm::vec3 entityDirectionGetVector(const EntityDirection &dir);

/**
 * Gets the relative tile position for the given direction.
 * 
 * @param pos The current position.
 * @param dir The direction to get the relative position for.
 * @param distance The distance to get the relative position for.
 * @return The relative tile position for the given direction.
 */
struct Dawn::EntityTilePosition entityDirectionGetRelativeTilePosition(
  const Dawn::EntityTilePosition &pos,
  const EntityDirection &dir,
  int32_t distance = 1
);